A trait that defines validation methods for a payment request.
This trait is used to ensure that the PaymentRequest object contains
valid data before processing. It provides methods to validate:
- The payment amount must be greater than zero.
- The currency code must be a valid 3-letter ISO 4217 string.
- The customer ID, if provided, must not be empty.
Traits
- Validatable
Request - This trait is used to ensure that the
PaymentRequestobject contains valid data before processing.